@@ -14,7 +14,7 @@ class Mask(np.ndarray):
 
     # noinspection PyUnusedLocal
     def __new__(
-            cls, mask_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), *args, **kwargs
+        cls, mask_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), *args, **kwargs
     ):
         """ A mask, which is applied to a 2D array of hyper_galaxies to extract a set of unmasked image pixels (i.e. mask entry \
         is *False* or 0) which are then fitted in an analysis.
@@ -37,12 +37,28 @@ class Mask(np.ndarray):
         mask_2d = mask_2d.astype("bool")
         obj = mask_2d.view(cls)
         obj.sub_size = sub_size
-        obj.sub_length = int(sub_size ** 2.0)
-        obj.sub_fraction = 1.0 / obj.sub_length
         obj.pixel_scales = pixel_scales
         obj.origin = origin
         return obj
 
+    def __reduce__(self):
+        # Get the parent's __reduce__ tuple
+        pickled_state = super(Mask, self).__reduce__()
+        # Create our own tuple to pass to __setstate__
+        class_dict = {}
+        for key, value in self.__dict__.items():
+            class_dict[key] = value
+        new_state = pickled_state[2] + (class_dict,)
+        # Return a tuple that replaces the parent's __setstate__ tuple with our own
+        return pickled_state[0], pickled_state[1], new_state
+
+    # noinspection PyMethodOverriding
+    def __setstate__(self, state):
+
+        for key, value in state[-1].items():
+            setattr(self, key, value)
+        super(Mask, self).__setstate__(state[0:-1])
+
     @property
     def mapping(self):
         return mapping.Mapping(mask=self)
@@ -59,14 +75,16 @@ class Mask(np.ndarray):
 
         if isinstance(obj, Mask):
             self.sub_size = obj.sub_size
-            self.sub_length = obj.sub_length
-            self.sub_fraction = obj.sub_fraction
             self.pixel_scales = obj.pixel_scales
             self.origin = obj.origin
+        else:
+            self.sub_size = 1
+            self.origin = (0.0, 0.0)
+            self.pixel_scales = None
 
     @classmethod
     def manual(
-            cls, mask_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), invert=False
+        cls, mask_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), invert=False
     ):
 
         if type(mask_2d) is list:
@@ -87,7 +105,7 @@ class Mask(np.ndarray):
 
     @classmethod
     def unmasked(
-            cls, shape_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), invert=False
+        cls, shape_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), invert=False
     ):
         """Setup a mask where all pixels are unmasked.
 
@@ -106,16 +124,24 @@ class Mask(np.ndarray):
             invert=invert,
         )
 
+    @property
+    def sub_length(self):
+        return int(self.sub_size ** 2.0)
+
+    @property
+    def sub_fraction(self):
+        return 1.0 / self.sub_length
+
     @classmethod
     def circular(
-            cls,
-            shape_2d,
-            radius,
-            pixel_scales,
-            sub_size=1,
-            origin=(0.0, 0.0),
-            centre=(0.0, 0.0),
-            invert=False,
+        cls,
+        shape_2d,
+        radius,
+        pixel_scales,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        centre=(0.0, 0.0),
+        invert=False,
     ):
         """Setup a mask where unmasked pixels are within a circle of an input arc second radius and centre.
 
@@ -136,10 +162,7 @@ class Mask(np.ndarray):
                 pixel_scales = (float(pixel_scales), float(pixel_scales))
 
         mask_2d = mask_util.mask_2d_circular_from_shape_2d_pixel_scales_and_radius(
-            shape_2d=shape_2d,
-            pixel_scales=pixel_scales,
-            radius=radius,
-            centre=centre,
+            shape_2d=shape_2d, pixel_scales=pixel_scales, radius=radius, centre=centre
         )
 
         return cls.manual(
@@ -152,15 +175,15 @@ class Mask(np.ndarray):
 
     @classmethod
     def circular_annular(
-            cls,
-            shape_2d,
-            inner_radius,
-            outer_radius,
-            pixel_scales,
-            sub_size=1,
-            origin=(0.0, 0.0),
-            centre=(0.0, 0.0),
-            invert=False,
+        cls,
+        shape_2d,
+        inner_radius,
+        outer_radius,
+        pixel_scales,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        centre=(0.0, 0.0),
+        invert=False,
     ):
         """Setup a mask where unmasked pixels are within an annulus of input inner and outer arc second radii and \
          centre.
@@ -201,16 +224,16 @@ class Mask(np.ndarray):
 
     @classmethod
     def circular_anti_annular(
-            cls,
-            shape_2d,
-            inner_radius,
-            outer_radius,
-            outer_radius_2,
-            pixel_scales,
-            sub_size=1,
-            origin=(0.0, 0.0),
-            centre=(0.0, 0.0),
-            invert=False,
+        cls,
+        shape_2d,
+        inner_radius,
+        outer_radius,
+        outer_radius_2,
+        pixel_scales,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        centre=(0.0, 0.0),
+        invert=False,
     ):
         """Setup a mask where unmasked pixels are outside an annulus of input inner and outer arc second radii, but \
         within a second outer radius, and at a given centre.
@@ -259,16 +282,16 @@ class Mask(np.ndarray):
 
     @classmethod
     def elliptical(
-            cls,
-            shape_2d,
-            major_axis_radius,
-            axis_ratio,
-            phi,
-            pixel_scales,
-            sub_size=1,
-            origin=(0.0, 0.0),
-            centre=(0.0, 0.0),
-            invert=False,
+        cls,
+        shape_2d,
+        major_axis_radius,
+        axis_ratio,
+        phi,
+        pixel_scales,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        centre=(0.0, 0.0),
+        invert=False,
     ):
         """ Setup a mask where unmasked pixels are within an ellipse of an input arc second major-axis and centre.
 
@@ -312,19 +335,19 @@ class Mask(np.ndarray):
 
     @classmethod
     def elliptical_annular(
-            cls,
-            shape_2d,
-            inner_major_axis_radius,
-            inner_axis_ratio,
-            inner_phi,
-            outer_major_axis_radius,
-            outer_axis_ratio,
-            outer_phi,
-            pixel_scales,
-            sub_size=1,
-            origin=(0.0, 0.0),
-            centre=(0.0, 0.0),
-            invert=False,
+        cls,
+        shape_2d,
+        inner_major_axis_radius,
+        inner_axis_ratio,
+        inner_phi,
+        outer_major_axis_radius,
+        outer_axis_ratio,
+        outer_phi,
+        pixel_scales,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        centre=(0.0, 0.0),
+        invert=False,
     ):
         """Setup a mask where unmasked pixels are within an elliptical annulus of input inner and outer arc second \
         major-axis and centre.
@@ -377,15 +400,39 @@ class Mask(np.ndarray):
             invert=invert,
         )
 
+    @classmethod
+    def from_pixel_coordinates(
+        cls,
+        shape_2d,
+        pixel_coordinates,
+        pixel_scales,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        buffer=0,
+        invert=False,
+    ):
+
+        mask_2d = mask_util.mask_2d_from_pixel_coordinates(
+            shape_2d=shape_2d, pixel_coordinates=pixel_coordinates, buffer=buffer
+        )
+
+        return cls.manual(
+            mask_2d=mask_2d,
+            pixel_scales=pixel_scales,
+            sub_size=sub_size,
+            origin=origin,
+            invert=invert,
+        )
+
     @classmethod
     def from_fits(
-            cls,
-            file_path,
-            pixel_scales,
-            hdu=0,
-            sub_size=1,
-            origin=(0.0, 0.0),
-            resized_mask_shape=None,
+        cls,
+        file_path,
+        pixel_scales,
+        hdu=0,
+        sub_size=1,
+        origin=(0.0, 0.0),
+        resized_mask_shape=None,
     ):
         """
         Loads the image from a .fits file.
@@ -460,7 +507,10 @@ class Mask(np.ndarray):
 
     @property
     def sub_shape_2d(self):
-        return (self.shape[0] * self.sub_size, self.shape[1] * self.sub_size)
+        try:
+            return (self.shape[0] * self.sub_size, self.shape[1] * self.sub_size)
+        except AttributeError:
+            print("bleh")
 
     @property
     def sub_mask_2d(self):
